-- ----------------------------------------------------------------------
-- MySQL Migration Toolkit
-- SQL Create Script
-- ----------------------------------------------------------------------

SET FOREIGN_KEY_CHECKS = 0;

DROP DATABASE IF EXISTS `muecke_1`;
CREATE DATABASE IF NOT EXISTS `muecke_1`
  CHARACTER SET utf8 COLLATE utf8_general_ci;
USE `muecke_1`;
-- -------------------------------------
-- Tables

CREATE TABLE `muecke_1`.`AufPos` (
  `aufposnr` VARCHAR(5) NOT NULL,
  `aufnr` VARCHAR(6) NULL,
  `posnr` VARCHAR(2) NULL,
  `fenr` VARCHAR(6) NULL,
  `menge` INT(4) NULL,
  `status` VARCHAR(1) NULL,
  PRIMARY KEY (`aufposnr`),
  INDEX `AUFTRAEGEAUFPOS` (`aufnr`),
  INDEX `Relation4` (`fenr`),
  CONSTRAINT `Relation4` FOREIGN KEY `Relation4` (`fenr`)
    REFERENCES `muecke_1`.`FE` (`fenr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_1`.`Auftraege` (
  `aufnr` VARCHAR(6) NOT NULL,
  `kdnr` VARCHAR(6) NULL,
  `aufdat` DATE NULL,
  PRIMARY KEY (`aufnr`),
  INDEX `KUNDENAUFTRAEGE` (`kdnr`),
  CONSTRAINT `KUNDENAUFTRAEGE` FOREIGN KEY `KUNDENAUFTRAEGE` (`kdnr`)
    REFERENCES `muecke_1`.`Kunden` (`kdnr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_1`.`FE` (
  `fenr` VARCHAR(6) NOT NULL,
  `febez` VARCHAR(50) NULL,
  `pgruppe` VARCHAR(3) NULL,
  `lbest` INT(4) NULL,
  `einh` VARCHAR(6) NULL,
  `hk` DECIMAL(6, 2) NULL,
  `znr` VARCHAR(5) NULL,
  PRIMARY KEY (`fenr`),
  INDEX `Relation6` (`znr`),
  CONSTRAINT `Relation6` FOREIGN KEY `Relation6` (`znr`)
    REFERENCES `muecke_1`.`Zuschlaege` (`znr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_1`.`Konditionen` (
  `kondnr` VARCHAR(5) NOT NULL,
  `skonto` INT(5) NULL,
  `tage` INT(5) NULL,
  `rabatt` INT(5) NULL,
  PRIMARY KEY (`kondnr`)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_1`.`Kunden` (
  `kdnr` VARCHAR(6) NOT NULL,
  `firma` VARCHAR(50) NULL,
  `strasse` VARCHAR(50) NULL,
  `ortnr` INT(10) NULL,
  `telefon` VARCHAR(20) NULL,
  `fax` VARCHAR(20) NULL,
  `email` VARCHAR(50) NULL,
  `erstlief` DATE NULL,
  `pnr` VARCHAR(10) NULL,
  `kondnr` VARCHAR(5) NULL,
  PRIMARY KEY (`kdnr`),
  INDEX `KONDITIONENKUNDEN` (`kondnr`),
  INDEX `PERSONALKUNDEN` (`pnr`),
  INDEX `WohnorteKUNDEN` (`ortnr`),
  CONSTRAINT `KONDITIONENKUNDEN` FOREIGN KEY `KONDITIONENKUNDEN` (`kondnr`)
    REFERENCES `muecke_1`.`Konditionen` (`kondnr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT,
  CONSTRAINT `PERSONALKUNDEN` FOREIGN KEY `PERSONALKUNDEN` (`pnr`)
    REFERENCES `muecke_1`.`Personal` (`pnr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT,
  CONSTRAINT `WohnorteKUNDEN` FOREIGN KEY `WohnorteKUNDEN` (`ortnr`)
    REFERENCES `muecke_1`.`Orte` (`ortnr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_1`.`Orte` (
  `ortnr` INT(10) NOT NULL,
  `plz` VARCHAR(5) NULL,
  `ort` VARCHAR(50) NULL,
  PRIMARY KEY (`ortnr`)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_1`.`Personal` (
  `pnr` VARCHAR(10) NOT NULL,
  `name` VARCHAR(20) NULL,
  `vorname` VARCHAR(15) NULL,
  `geschl` VARCHAR(1) NULL,
  `ortnr` INT(10) NULL,
  `plz` VARCHAR(5) NULL,
  `ort` VARCHAR(50) NULL,
  `strasse` VARCHAR(25) NULL,
  `gebtag` DATE NULL,
  `eintritt` DATE NULL,
  `stkl` VARCHAR(5) NULL,
  `gehalt` DOUBLE(8, 2) NULL,
  `kostnr` VARCHAR(2) NULL,
  PRIMARY KEY (`pnr`),
  INDEX `WohnortePERSONAL` (`ortnr`),
  CONSTRAINT `WohnortePERSONAL` FOREIGN KEY `WohnortePERSONAL` (`ortnr`)
    REFERENCES `muecke_1`.`Orte` (`ortnr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_1`.`Zuschlaege` (
  `znr` VARCHAR(5) NOT NULL,
  `z_satz` INT(3) NULL,
  PRIMARY KEY (`znr`)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;



SET FOREIGN_KEY_CHECKS = 1;

-- ----------------------------------------------------------------------
-- EOF

