-- ----------------------------------------------------------------------
-- MySQL Migration Toolkit
-- SQL Create Script
-- ----------------------------------------------------------------------

SET FOREIGN_KEY_CHECKS = 0;

DROP DATABASE IF EXISTS `muecke_2`;
CREATE DATABASE IF NOT EXISTS `muecke_2`
  CHARACTER SET utf8 COLLATE utf8_general_ci;
USE `muecke_2`;
-- -------------------------------------
-- Tables

CREATE TABLE `muecke_2`.`AUF_POS` (
  `Aufposnr` VARCHAR(50) NOT NULL,
  `AufNr` VARCHAR(6) NULL,
  `PosNr` VARCHAR(2) NULL,
  `FENr` VARCHAR(6) NULL,
  `Menge` INT(4) NULL,
  `Status` VARCHAR(1) NULL,
  PRIMARY KEY (`Aufposnr`),
  INDEX `AUFTRAEGEAUF_POS` (`AufNr`),
  INDEX `FEAUF_POS` (`FENr`),
  CONSTRAINT `AUFTRAEGEAUF_POS` FOREIGN KEY `AUFTRAEGEAUF_POS` (`AufNr`)
    REFERENCES `muecke_2`.`AUFTRAEGE` (`AufNr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT,
  CONSTRAINT `FEAUF_POS` FOREIGN KEY `FEAUF_POS` (`FENr`)
    REFERENCES `muecke_2`.`FE` (`FENr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_2`.`AUFTRAEGE` (
  `AufNr` VARCHAR(6) NOT NULL,
  `KdNr` VARCHAR(6) NULL,
  `AufDat` DATE NULL,
  PRIMARY KEY (`AufNr`),
  INDEX `KUNDENAUFTRAEGE` (`KdNr`),
  CONSTRAINT `KUNDENAUFTRAEGE` FOREIGN KEY `KUNDENAUFTRAEGE` (`KdNr`)
    REFERENCES `muecke_2`.`KUNDEN` (`KdNr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_2`.`BANKEN` (
  `Blz` INT(10) NOT NULL,
  `Bankname` VARCHAR(58) NULL,
  `Ort` VARCHAR(30) NULL,
  PRIMARY KEY (`Blz`)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_2`.`FE` (
  `FENr` VARCHAR(6) NOT NULL,
  `FEBez` VARCHAR(50) NULL,
  `PGruppe` VARCHAR(3) NULL,
  `LBest` INT(4) NULL,
  `Einh` VARCHAR(6) NULL,
  `HK` DECIMAL(6, 2) NULL,
  `ZNr` VARCHAR(5) NULL,
  PRIMARY KEY (`FENr`),
  INDEX `ZUSCHLAEGEFE` (`ZNr`),
  CONSTRAINT `ZUSCHLAEGEFE` FOREIGN KEY `ZUSCHLAEGEFE` (`ZNr`)
    REFERENCES `muecke_2`.`ZUSCHLAEGE` (`ZNr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_2`.`GEHAELTER` (
  `PNr` VARCHAR(6) NOT NULL,
  `Gehalt` DECIMAL(8, 2) NULL,
  PRIMARY KEY (`PNr`),
  UNIQUE INDEX `PERSONALGEHAELTER` (`PNr`),
  CONSTRAINT `PERSONALGEHAELTER` FOREIGN KEY `PERSONALGEHAELTER` (`PNr`)
    REFERENCES `muecke_2`.`PERSONAL` (`PNr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_2`.`KONDITIONEN` (
  `KondNr` VARCHAR(5) NOT NULL,
  `Skonto` INT(10) NULL,
  `Tage` INT(5) NULL,
  `Rabatt` INT(10) NULL,
  PRIMARY KEY (`KondNr`)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_2`.`KUNDEN` (
  `KdNr` VARCHAR(6) NOT NULL,
  `Firma` VARCHAR(50) NULL,
  `Strasse` VARCHAR(50) NULL,
  `OrtNr` VARCHAR(5) NULL,
  `Telefon` VARCHAR(20) NULL,
  `Fax` VARCHAR(20) NULL,
  `Email` VARCHAR(50) NULL,
  `erstlief` DATE NULL,
  `PNr` VARCHAR(10) NULL,
  `umsatz` INT(10) NULL,
  `KondNr` VARCHAR(5) NULL,
  PRIMARY KEY (`KdNr`),
  INDEX `KONDITIONENKUNDEN` (`KondNr`),
  INDEX `OrteKUNDEN` (`OrtNr`),
  INDEX `PERSONALKUNDEN` (`PNr`),
  CONSTRAINT `KONDITIONENKUNDEN` FOREIGN KEY `KONDITIONENKUNDEN` (`KondNr`)
    REFERENCES `muecke_2`.`KONDITIONEN` (`KondNr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT,
  CONSTRAINT `OrteKUNDEN` FOREIGN KEY `OrteKUNDEN` (`OrtNr`)
    REFERENCES `muecke_2`.`Orte` (`OrtNr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT,
  CONSTRAINT `PERSONALKUNDEN` FOREIGN KEY `PERSONALKUNDEN` (`PNr`)
    REFERENCES `muecke_2`.`PERSONAL` (`PNr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_2`.`LOEHNE` (
  `PNr` VARCHAR(6) NOT NULL,
  `Stundenlohn` DECIMAL(5, 2) NULL,
  PRIMARY KEY (`PNr`),
  UNIQUE INDEX `PERSONALLOEHNE` (`PNr`),
  CONSTRAINT `PERSONALLOEHNE` FOREIGN KEY `PERSONALLOEHNE` (`PNr`)
    REFERENCES `muecke_2`.`PERSONAL` (`PNr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_2`.`Orte` (
  `OrtNr` VARCHAR(5) NOT NULL,
  `PLZ` VARCHAR(5) NULL,
  `OrtName` VARCHAR(50) NULL,
  PRIMARY KEY (`OrtNr`)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_2`.`PERSONAL` (
  `PNr` VARCHAR(6) NOT NULL,
  `Name` VARCHAR(20) NULL,
  `Vorname` VARCHAR(15) NULL,
  `Geschl` VARCHAR(1) NULL,
  `OrtNr` VARCHAR(5) NULL,
  `Strasse` VARCHAR(25) NULL,
  `GebTag` DATE NULL,
  `Eintritt` DATE NULL,
  `StKl` VARCHAR(5) NULL,
  `KoStNr` VARCHAR(2) NULL,
  `Blz` INT(10) NULL,
  `KtoNr` VARCHAR(20) NULL,
  PRIMARY KEY (`PNr`),
  INDEX `BANKENPERSONAL` (`Blz`),
  INDEX `OrtePERSONAL` (`OrtNr`),
  CONSTRAINT `BANKENPERSONAL` FOREIGN KEY `BANKENPERSONAL` (`Blz`)
    REFERENCES `muecke_2`.`BANKEN` (`Blz`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT,
  CONSTRAINT `OrtePERSONAL` FOREIGN KEY `OrtePERSONAL` (`OrtNr`)
    REFERENCES `muecke_2`.`Orte` (`OrtNr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_2`.`ZULAGEN` (
  `PNR` VARCHAR(6) NOT NULL,
  `Zulage` DECIMAL(6, 2) NOT NULL,
  PRIMARY KEY (`PNR`, `Zulage`)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke_2`.`ZUSCHLAEGE` (
  `ZNr` VARCHAR(5) NOT NULL,
  `Z_Satz` INT(3) NOT NULL,
  PRIMARY KEY (`ZNr`)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;



SET FOREIGN_KEY_CHECKS = 1;

-- ----------------------------------------------------------------------
-- EOF

