-- ----------------------------------------------------------------------
-- MySQL Migration Toolkit
-- SQL Create Script
-- ----------------------------------------------------------------------

SET FOREIGN_KEY_CHECKS = 0;

DROP DATABASE IF EXISTS `muecke`;
CREATE DATABASE IF NOT EXISTS `muecke`
  CHARACTER SET utf8 COLLATE utf8_general_ci;
USE `muecke`;
-- -------------------------------------
-- Tables

CREATE TABLE `muecke`.`AufPos` (
  `aufposnr` VARCHAR(5) NOT NULL,
  `aufnr` VARCHAR(6) NULL,
  `posnr` VARCHAR(2) NULL,
  `fenr` VARCHAR(6) NULL,
  `menge` INT(4) NULL,
  `status` VARCHAR(1) NULL,
  PRIMARY KEY (`aufposnr`),
  INDEX `AUFTRAEGEAUFPOS` (`aufnr`),
  INDEX `FEAUFPOS` (`fenr`),
  CONSTRAINT `FEAUFPOS` FOREIGN KEY `FEAUFPOS` (`fenr`)
    REFERENCES `muecke`.`FE` (`fenr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke`.`Auftraege` (
  `aufnr` VARCHAR(6) NOT NULL,
  `kdnr` VARCHAR(6) NULL,
  `aufdat` DATE NULL,
  PRIMARY KEY (`aufnr`),
  INDEX `KUNDENAUFTRAEGE` (`kdnr`)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke`.`FE` (
  `fenr` VARCHAR(6) NOT NULL,
  `febez` VARCHAR(50) NULL,
  `pgruppe` VARCHAR(3) NULL,
  `lbest` INT(4) NULL,
  `einh` VARCHAR(6) NULL,
  `hk` DECIMAL(6, 2) NULL,
  `znr` VARCHAR(5) NULL,
  PRIMARY KEY (`fenr`),
  INDEX `Relation6` (`znr`),
  CONSTRAINT `Relation6` FOREIGN KEY `Relation6` (`znr`)
    REFERENCES `muecke`.`Zuschlaege` (`znr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke`.`Konditionen` (
  `kondnr` VARCHAR(5) NOT NULL,
  `skonto` INT(5) NULL,
  `tage` INT(5) NULL,
  `rabatt` INT(5) NULL,
  PRIMARY KEY (`kondnr`)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke`.`Kunden` (
  `kdnr` VARCHAR(6) NOT NULL,
  `firma` VARCHAR(50) NULL,
  `strasse` VARCHAR(50) NULL,
  `ortnr` INT(10) NULL,
  `telefon` VARCHAR(20) NULL,
  `fax` VARCHAR(20) NULL,
  `email` VARCHAR(50) NULL,
  `pnr` VARCHAR(10) NULL,
  `kondnr` VARCHAR(5) NULL,
  PRIMARY KEY (`kdnr`),
  INDEX `KONDITIONENKUNDEN` (`kondnr`),
  INDEX `OrteKUNDEN` (`ortnr`),
  INDEX `PERSONALKUNDEN` (`pnr`),
  CONSTRAINT `KONDITIONENKUNDEN` FOREIGN KEY `KONDITIONENKUNDEN` (`kondnr`)
    REFERENCES `muecke`.`Konditionen` (`kondnr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT,
  CONSTRAINT `OrteKUNDEN` FOREIGN KEY `OrteKUNDEN` (`ortnr`)
    REFERENCES `muecke`.`Orte` (`ortnr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT,
  CONSTRAINT `PERSONALKUNDEN` FOREIGN KEY `PERSONALKUNDEN` (`pnr`)
    REFERENCES `muecke`.`Personal` (`pnr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke`.`Orte` (
  `ortnr` INT(10) NOT NULL,
  `plz` VARCHAR(5) NULL,
  `ortname` VARCHAR(50) NULL,
  PRIMARY KEY (`ortnr`)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke`.`Personal` (
  `pnr` VARCHAR(10) NOT NULL,
  `name` VARCHAR(20) NULL,
  `vorname` VARCHAR(15) NULL,
  `telefon` VARCHAR(30) NULL,
  PRIMARY KEY (`pnr`)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `muecke`.`Zuschlaege` (
  `znr` VARCHAR(5) NOT NULL,
  `z_satz` INT(3) NULL,
  PRIMARY KEY (`znr`)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;



SET FOREIGN_KEY_CHECKS = 1;

-- ----------------------------------------------------------------------
-- EOF

